@@ -26,7 +26,7 @@ use Time::HiRes qw/time/;
 Readonly my $HTTP_OK => 200;
 Readonly my $HTTP_FILE_NOT_FOUND => 404;
 
-our $VERSION = '1.23';
+our $VERSION = '1.24';
 
 # TODO: Timeout, fallback
 # TODO: Expected result content (json etc)
@@ -152,7 +152,7 @@ sub build_tx {
 sub start {
   my ($self, $tx, $cb) = @_;
 
-  my $url     = $tx->req->url;
+  my $url     = $tx->req->url->to_unsafe_string;
   my $method  = $tx->req->method;
   my $headers = $tx->req->headers->to_hash(1);
   my $content = $tx->req->content->asset->slurp;
